@@ -466,6 +466,11 @@ class CountrySettingsPackage(Package):
 
         options.update(self.config_applications)
 
+        # add extrafiles information
+        options['extra_files'] = {}
+        for key,binary in self.extra_files.iteritems():
+            options['extra_files'][binary.name] = binary.relative_filepath
+
         # main config file
         main_config = get_custom_file('product', self.name, self.template)
         main_config.build(
@@ -475,4 +480,7 @@ class CountrySettingsPackage(Package):
             )
 
     def get_service_dependencies(self):
+        #import ipdb; ipdb.set_trace()
+        if self.config_applications == []:
+            return {}
         return list(self.config_applications.keys())
